var Auth, Config, Express, Fs, Path, User, apiUserPasswordFunction, app;
Fs = require("fs");
Auth = require("connect-auth");
Path = require("path");
User = require("user");
Express = require("express");
app = Express.createServer();
Config = {
  scope: "email,offline_access",
  appId: process.env.GITHUB_CLIENT_ID,
  appSecret: process.env.GITHUB_CLIENT_SECRET,
  callback: process.env.GITHUB_CALLBACK,
  sessionSecret: process.env.GITHUB_SESSION_SECRET || "unknown",
  apiPassword: process.env.JINKIES_API_PASSWORD || "password",
  organization: process.env.JINKIES_ORGANIZATION || "github"
};
apiUserPasswordFunction = function(username, password, successCallback, failureCallback) {
  if (username === "api" && password === Config.apiPassword) {
    return successCallback();
  } else {
    return failureCallback();
  }
};
app.configure(function() {
  app.set("root", Path.join(__filename, "..", ".."));
  app.set("view engine", "ejs");
  app.set("views", Path.join(__filename, "..", "..", "views"));
  app.use(Express.logger());
  app.use(Express.methodOverride());
  app.use(Express.errorHandler({
    showStack: true,
    dumpExceptions: true
  }));
  app.use(Express.static(Path.join(__filename, "..", "..", "public")));
  app.use(Express.cookieParser());
  app.use(Express.session({
    secret: Config.sessionSecret,
    lifetime: 150000,
    reapInterval: 10000
  }));
  app.use(Auth([
    Auth.Anonymous(), Auth.Basic({
      validatePassword: apiUserPasswordFunction
    }), Auth.Github(Config)
  ]));
  return app.use(Express.bodyParser());
});
app.get("/auth/github/callback", function(req, res) {
  return req.authenticate(["github"], function(err, success) {
    var user;
    if (success) {
      user = new User.User(req.getAuthDetails().user);
      return user.memberOf(Config.organization, function(err, isMember) {
        if (isMember) {
          return res.redirect("/jobs");
        } else {
          return res.redirect("/auth/failure");
        }
      });
    } else {
      return res.redirect("/auth/failure");
    }
  });
});
app.get("/auth/failure", function(req, res) {
  return res.render("failure", {
    title: "Unable to Authenticate, bummer."
  });
});
app.get("/auth/login", function(req, res) {
  return res.render("login", {
    title: "Login to our Janky CI Server with GitHub!"
  });
});
app.get("/auth/logout", function(req, res) {
  req.logout();
  return res.redirect("/jobs", 303);
});
app.post("/", function(req, res) {
  var branch, info, job, owner, project;
  info = JSON.parse(req.body.payload);
  owner = info.repository.owner.name;
  branch = info["ref"].split("/")[2];
  project = "" + owner + "-" + info.repository.name;
  if (info.deleted || (info.created && info.commits.length === 0)) {
    ;
  } else {
    job = app.jinkies.job_for(project);
    return job.triggerBuild(branch, req.body.payload, function(err, data) {
      return res.send(data, {
        "Content-Type": "application/json"
      }, 200);
    });
  }
});
app.all("*", function(req, res, next) {
  if (req.headers.accept === "application/json") {
    if (req.socket.remoteAddress === '127.0.0.1') {
      return next();
    } else {
      return req.authenticate(["basic"], function(err, success) {
        if (success) {
          return next();
        } else {
          return res.send("Unauthorized", 401);
        }
      });
    }
  } else {
    if (req.isAuthenticated()) {
      return next();
    } else {
      return res.redirect("/auth/login");
    }
  }
});
app.get("/jobs", function(req, res) {
  return app.jinkies.jobs_info(function(err, jobs) {
    if (req.headers.accept === "application/json") {
      return res.send(jobs, {
        "Content-Type": "application/json"
      }, 200);
    } else {
      return res.render("index", {
        title: "Janky CI Server",
        jobs: jobs
      });
    }
  });
});
app.get("/jobs/:job", function(req, res) {
  var job;
  job = app.jinkies.job_for(req.params.job);
  return job.info(function(err, info) {
    return res.send(info, {
      "Content-Type": "application/json"
    }, 200);
  });
});
app.post("/jobs/:job/builds", function(req, res) {
  var branch_name, job;
  job = app.jinkies.job_for(req.params.job);
  branch_name = req.body.branch || "master";
  return job.triggerBuild(branch_name, "{}", function(err, data) {
    return res.send(data, {
      "Content-Type": "application/json"
    }, 200);
  });
});
app.get("/jobs/:job/builds/:build", function(req, res) {
  var job;
  job = app.jinkies.job_for(req.params.job);
  return job.build_for(req.params.build, function(err, build) {
    return res.send(build, {
      "Content-Type": "application/json"
    }, 200);
  });
});
app.get("/jobs/:job/builds/:build/console", function(req, res) {
  var job, name, number;
  name = req.params.job;
  number = req.params.build;
  job = app.jinkies.job_for(name);
  return job.build_for(number, function(err, build) {
    var title;
    title = "Build output for " + name + " # " + number;
    return res.render("console", {
      title: title,
      output: build.consoleText
    });
  });
});
app.get("/jobs/:job/branches/:branch", function(req, res) {
  var job;
  job = app.jinkies.job_for(req.params.job);
  return job.branches_for(req.params.branch, function(err, branches) {
    return res.send(branches, {
      "Content-Type": "application/json"
    }, 200);
  });
});
exports.App = app;